<!--

Version codenames style:

date "+## %Y.%m.%d -- {adjective} {colorname}" | pbcopy

https://patternbasedwriting.com/elementary_writing_success/list-4800-adjectives/
https://en.wikipedia.org/wiki/Lists_of_colors

-->

```{include} ../../../CHANGELOG.md
```